@@ -2,8 +2,6 @@
 *
 * Copyright (c) 2003-2011, PostgreSQL Global Development Group
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/core/BaseConnection.java,v 1.25 2011/08/02 13:40:12 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -65,10 +63,11 @@ public interface BaseConnection extends PGConnection, Connection
      *
      * @param type the backend typename
      * @param value the type-specific string representation of the value
+     * @param byteValue the type-specific binary representation of the value
      * @return an appropriate object; never null.
      * @throws SQLException if something goes wrong
      */
-    public Object getObject(String type, String value) throws SQLException;
+    public Object getObject(String type, String value, byte[] byteValue) throws SQLException;
 
     public Encoding getEncoding() throws SQLException;
 
@@ -146,4 +145,13 @@ public interface BaseConnection extends PGConnection, Connection
      * @return a ProtocolConnection.TRANSACTION_* constant.
      */
     public int getTransactionState();
+
+    /**
+     * Returns true if value for the given oid should be sent using binary
+     * transfer. False if value should be sent using text transfer.
+     *
+     * @param oid The oid to check.
+     * @return True for binary transfer, false for text transfer.
+     */
+    public boolean binaryTransferSend(int oid);
 }
