@@ -2,8 +2,6 @@
 *
 * Copyright (c) 2003-2011, PostgreSQL Global Development Group
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/core/BaseResultSet.java,v 1.11 2011/08/02 13:40:12 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -27,5 +25,4 @@ public interface BaseResultSet extends ResultSet
      */
     public String getFixedString(int col) throws SQLException;
 
-    public Array createArray(int col) throws SQLException;
 }
