@@ -3,8 +3,6 @@
 * Copyright (c) 2004-2011, PostgreSQL Global Development Group
 * Copyright (c) 2004, Open Cloud Limited.
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/core/ConnectionFactory.java,v 1.10 2011/08/02 13:40:12 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -13,6 +11,7 @@ package org.postgresql.core;
 import java.util.Properties;
 import java.sql.SQLException;
 
+import org.postgresql.util.HostSpec;
 import org.postgresql.util.PSQLException;
 import org.postgresql.util.GT;
 import org.postgresql.util.PSQLState;
@@ -43,8 +42,7 @@ public abstract class ConnectionFactory {
      *<p>
      * Currently, protocol versions 3 (7.4+) and 2 (pre-7.4) are supported.
      *
-     * @param host the host to connect to
-     * @param port the port to connect to
+     * @param hostSpecs at least one host and port to connect to; multiple elements for round-robin failover
      * @param user the username to authenticate with; may not be null.
      * @param database the database on the server to connect to; may not be null.
      * @param info extra properties controlling the connection;
@@ -53,7 +51,7 @@ public abstract class ConnectionFactory {
      * @return the new, initialized, connection
      * @throws SQLException if the connection could not be established.
      */
-    public static ProtocolConnection openConnection(String host, int port, String user, String database, Properties info, Logger logger) throws SQLException {
+    public static ProtocolConnection openConnection(HostSpec[] hostSpecs, String user, String database, Properties info, Logger logger) throws SQLException {
         String protoName = info.getProperty("protocolVersion");
 
         for (int i = 0; i < versions.length; ++i)
@@ -63,7 +61,7 @@ public abstract class ConnectionFactory {
                 continue;
 
             ConnectionFactory factory = (ConnectionFactory) versions[i][1];
-            ProtocolConnection connection = factory.openConnectionImpl(host, port, user, database, info, logger);
+            ProtocolConnection connection = factory.openConnectionImpl(hostSpecs, user, database, info, logger);
             if (connection != null)
                 return connection;
         }
@@ -76,8 +74,7 @@ public abstract class ConnectionFactory {
      * Implementation of {@link #openConnection} for a particular protocol version.
      * Implemented by subclasses of {@link ConnectionFactory}.
      *
-     * @param host the host to connect to
-     * @param port the port to connect to
+     * @param hostSpecs at least one host and port to connect to; multiple elements for round-robin failover
      * @param user the username to authenticate with; may not be null.
      * @param database the database on the server to connect to; may not be null.
      * @param info extra properties controlling the connection;
@@ -88,5 +85,5 @@ public abstract class ConnectionFactory {
      * @throws SQLException if the connection could not be established for a reason other
      *    than protocol version incompatibility.
      */
-    public abstract ProtocolConnection openConnectionImpl(String host, int port, String user, String database, Properties info, Logger logger) throws SQLException;
+    public abstract ProtocolConnection openConnectionImpl(HostSpec[] hostSpecs, String user, String database, Properties info, Logger logger) throws SQLException;
 }
