@@ -3,8 +3,6 @@
 * Copyright (c) 2004-2011, PostgreSQL Global Development Group
 * Copyright (c) 2004, Open Cloud Limited.
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/core/ParameterList.java,v 1.11 2011/08/02 13:40:12 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -122,6 +120,17 @@ public interface ParameterList {
      */
     void setBytea(int index, InputStream stream, int length) throws SQLException;
 
+    /**
+     * Binds given byte[] value to a parameter. The bytes must already
+     * be in correct format matching the OID.
+     *
+     * @param index the 1-based parameter index to bind.
+     * @param value the bytes to send.
+     * @param oid the type OID of the parameter.
+     * @throws SQLException on error or if <code>index</code> is out of range
+     */
+    void setBinaryParameter(int index, byte[] value, int oid) throws SQLException;
+
     /**
      * Binds a SQL NULL value to a parameter.
      * Associated with the parameter is a typename for the parameter that
