@@ -3,8 +3,6 @@
 * Copyright (c) 2003-2011, PostgreSQL Global Development Group
 * Copyright (c) 2004, Open Cloud Limited.
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/core/QueryExecutor.java,v 1.47 2011/08/02 13:40:12 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -97,6 +95,11 @@ public interface QueryExecutor {
      */
     static int QUERY_DISALLOW_BATCHING = 128;
 
+    /**
+     * Flag for query execution to avoid using binary transfer.
+     */
+    static int QUERY_NO_BINARY_TRANSFER = 256;
+
     /**
      * Execute a Query, passing results to a provided ResultHandler.
      *
