@@ -3,8 +3,6 @@
 * Copyright (c) 2003-2011, PostgreSQL Global Development Group
 * Copyright (c) 2004, Open Cloud Limited.
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/core/v2/ConnectionFactoryImpl.java,v 1.23 2011/08/02 13:40:12 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -13,17 +11,18 @@ package org.postgresql.core.v2;
 import java.util.Properties;
 import java.util.StringTokenizer;
 
-import java.sql.*;
+import java.sql.SQLException;
+import java.sql.SQLWarning;
 import java.io.IOException;
 import java.net.ConnectException;
 
-import org.postgresql.Driver;
 import org.postgresql.core.*;
 import org.postgresql.util.PSQLException;
 import org.postgresql.util.PSQLState;
 import org.postgresql.util.UnixCrypt;
 import org.postgresql.util.MD5Digest;
 import org.postgresql.util.GT;
+import org.postgresql.util.HostSpec;
 
 /**
  * ConnectionFactory implementation for version 2 (pre-7.4) connections.
@@ -39,26 +38,52 @@ public class ConnectionFactoryImpl extends ConnectionFactory {
     private static final int AUTH_REQ_MD5 = 5;
     private static final int AUTH_REQ_SCM = 6;
 
-    public ProtocolConnection openConnectionImpl(String host, int port, String user, String database, Properties info, Logger logger) throws SQLException {
+    public ProtocolConnection openConnectionImpl(HostSpec[] hostSpecs, String user, String database, Properties info, Logger logger) throws SQLException {
         // Extract interesting values from the info properties:
         //  - the SSL setting
-        boolean requireSSL = (info.getProperty("ssl") != null);
-        boolean trySSL = requireSSL; // XXX temporary until we revisit the ssl property values
+        boolean requireSSL;
+        boolean trySSL;
+        String sslmode = info.getProperty("sslmode");
+        if (sslmode==null)
+        { //Fall back to the ssl property
+          requireSSL = trySSL  = (info.getProperty("ssl") != null);
+        } else {
+          if ("disable".equals(sslmode))
+          {
+            requireSSL = trySSL = false;
+          }
+          //allow and prefer are not handled yet
+          /*else if ("allow".equals(sslmode) || "prefer".equals(sslmode))
+          {  
+            //XXX Allow and prefer are treated the same way
+            requireSSL = false;
+            trySSL = true;
+          }*/
+          else if ("require".equals(sslmode) || "verify-ca".equals(sslmode) || "verify-full".equals(sslmode))
+          {
+            requireSSL = trySSL = true;
+          } else {
+            throw new PSQLException (GT.tr("Invalid sslmode value: {0}", sslmode), PSQLState.CONNECTION_UNABLE_TO_CONNECT);
+          }
+        }
 
         //  - the TCP keep alive setting
         boolean requireTCPKeepAlive = (Boolean.valueOf(info.getProperty("tcpKeepAlive")).booleanValue());
 
-        if (logger.logDebug())
-            logger.debug("Trying to establish a protocol version 2 connection to " + host + ":" + port);
+        for (int whichHost = 0; whichHost < hostSpecs.length; ++whichHost) {
+            HostSpec hostSpec = hostSpecs[whichHost];
+            if (logger.logDebug())
+                logger.debug("Trying to establish a protocol version 2 connection to " + hostSpec);
 
-        //
-        // Establish a connection.
-        //
+            //
+            // Establish a connection.
+            //
+            
 
         PGStream newStream = null;
         try
         {
-            newStream = new PGStream(host, port);
+            newStream = new PGStream(hostSpec);
 
             // Construct and send an ssl startup packet if requested.
             if (trySSL)
@@ -101,6 +126,11 @@ public class ConnectionFactoryImpl extends ConnectionFactory {
             // Added by Peter Mount <peter@retep.org.uk>
             // ConnectException is thrown when the connection cannot be made.
             // we trap this an return a more meaningful message for the end user
+
+            if (whichHost + 1 < hostSpecs.length) {
+                // still more addresses to try
+                continue;
+            }
             throw new PSQLException (GT.tr("Connection refused. Check that the hostname and port are correct and that the postmaster is accepting TCP/IP connections."), PSQLState.CONNECTION_UNABLE_TO_CONNECT, cex);
         }
         catch (IOException ioe)
@@ -116,6 +146,10 @@ public class ConnectionFactoryImpl extends ConnectionFactory {
                 }
             }
 
+            if (whichHost + 1 < hostSpecs.length) {
+                // still more addresses to try
+                continue;
+            }
             throw new PSQLException (GT.tr("The connection attempt failed."), PSQLState.CONNECTION_UNABLE_TO_CONNECT, ioe);
         }
         catch (SQLException se)
@@ -131,8 +165,14 @@ public class ConnectionFactoryImpl extends ConnectionFactory {
                 }
             }
 
+            if (whichHost + 1 < hostSpecs.length) {
+                // still more addresses to try
+                continue;
+            }
             throw se;
         }
+        }
+        throw new PSQLException (GT.tr("The connection url is invalid."), PSQLState.CONNECTION_UNABLE_TO_CONNECT);
     }
 
     private PGStream enableSSL(PGStream pgStream, boolean requireSSL, Properties info, Logger logger) throws IOException, SQLException {
@@ -159,7 +199,7 @@ public class ConnectionFactoryImpl extends ConnectionFactory {
 
             // We have to reconnect to continue.
             pgStream.close();
-            return new PGStream(pgStream.getHost(), pgStream.getPort());
+            return new PGStream(pgStream.getHostSpec());
 
         case 'N':
             if (logger.logDebug())
