@@ -3,8 +3,6 @@
 * Copyright (c) 2004-2011, PostgreSQL Global Development Group
 * Copyright (c) 2004, Open Cloud Limited.
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/core/v2/FastpathParameterList.java,v 1.11 2011/08/02 13:40:12 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -155,6 +153,10 @@ class FastpathParameterList implements ParameterList {
         Arrays.fill(paramValues, null);
     }
 
+    public void setBinaryParameter(int index, byte[] value, int oid) {
+        throw new UnsupportedOperationException();
+    }
+
     private final Object[] paramValues;
 }
 
