@@ -3,19 +3,20 @@
 * Copyright (c) 2004-2011, PostgreSQL Global Development Group
 * Copyright (c) 2004, Open Cloud Limited.
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/core/v2/ProtocolConnectionImpl.java,v 1.13 2011/08/02 13:40:12 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
 package org.postgresql.core.v2;
 
-import java.sql.*;
+import java.sql.SQLException;
+import java.sql.SQLWarning;
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.Set;
 
 import org.postgresql.PGNotification;
 import org.postgresql.core.*;
+import org.postgresql.util.HostSpec;
 
 /**
  * V2 implementation of ProtocolConnection.
@@ -31,12 +32,8 @@ class ProtocolConnectionImpl implements ProtocolConnection {
         this.executor = new QueryExecutorImpl(this, pgStream, logger);
     }
 
-    public String getHost() {
-        return pgStream.getHost();
-    }
-
-    public int getPort() {
-        return pgStream.getPort();
+    public HostSpec getHostSpec() {
+        return pgStream.getHostSpec();
     }
 
     public String getUser() {
@@ -90,7 +87,7 @@ class ProtocolConnectionImpl implements ProtocolConnection {
             if (logger.logDebug())
                 logger.debug(" FE=> CancelRequest(pid=" + cancelPid + ",ckey=" + cancelKey + ")");
 
-            cancelStream = new PGStream(pgStream.getHost(), pgStream.getPort());
+            cancelStream = new PGStream(pgStream.getHostSpec());
             cancelStream.SendInteger4(16);
             cancelStream.SendInteger2(1234);
             cancelStream.SendInteger2(5678);
@@ -201,6 +198,15 @@ class ProtocolConnectionImpl implements ProtocolConnection {
         return 2;
     }
     
+    public void setBinaryReceiveOids(Set<Integer> ignored) {
+        // ignored for v2 connections
+    }
+
+    public boolean getIntegerDateTimes() {
+        // not supported in v2 protocol
+        return false;
+    }
+
     private String serverVersion;
     private int cancelPid;
     private int cancelKey;
