@@ -3,8 +3,6 @@
 * Copyright (c) 2004-2011, PostgreSQL Global Development Group
 * Copyright (c) 2004, Open Cloud Limited.
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/core/v3/ProtocolConnectionImpl.java,v 1.14 2011/08/02 13:40:12 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -12,12 +10,17 @@ package org.postgresql.core.v3;
 
 import org.postgresql.PGNotification;
 import org.postgresql.core.*;
+import org.postgresql.util.HostSpec;
 
-import java.sql.*;
+import java.sql.SQLException;
+import java.sql.SQLWarning;
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.Set;
+import java.util.HashSet;
 import java.util.Properties;
 
+
 /**
  * ProtocolConnection implementation for the V3 protocol.
  *
@@ -34,12 +37,8 @@ class ProtocolConnectionImpl implements ProtocolConnection {
         this.standardConformingStrings = false;
     }
 
-    public String getHost() {
-        return pgStream.getHost();
-    }
-
-    public int getPort() {
-        return pgStream.getPort();
+    public HostSpec getHostSpec() {
+        return pgStream.getHostSpec();
     }
 
     public String getUser() {
@@ -90,7 +89,7 @@ class ProtocolConnectionImpl implements ProtocolConnection {
             if (logger.logDebug())
                 logger.debug(" FE=> CancelRequest(pid=" + cancelPid + ",ckey=" + cancelKey + ")");
 
-            cancelStream = new PGStream(pgStream.getHost(), pgStream.getPort());
+            cancelStream = new PGStream(pgStream.getHostSpec());
             cancelStream.SendInteger4(16);
             cancelStream.SendInteger2(1234);
             cancelStream.SendInteger2(5678);
@@ -200,6 +199,34 @@ class ProtocolConnectionImpl implements ProtocolConnection {
         return 3;
     }
 
+    public boolean useBinaryForReceive(int oid) {
+        return useBinaryForOids.contains(oid);
+    }
+
+    public void setBinaryReceiveOids(Set oids) {
+        useBinaryForOids.clear();
+        useBinaryForOids.addAll(oids);
+    }
+
+    public void setIntegerDateTimes(boolean state) {
+        integerDateTimes = state;
+    }
+
+    public boolean getIntegerDateTimes() {
+        return integerDateTimes;
+    }
+
+   /**
+     * True if server uses integers for date and time fields. False if
+     * server uses double.
+     */
+    private boolean integerDateTimes;
+
+    /**
+    * Bit set that has a bit set for each oid which should be received
+    * using binary format.
+    */
+    private final Set<Integer> useBinaryForOids = new HashSet<Integer>();
     private String serverVersion;
     private int cancelPid;
     private int cancelKey;
