@@ -2,8 +2,6 @@
 *
 * Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/ds/common/BaseDataSource.java,v 1.23 2011/08/02 13:42:25 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -51,8 +49,13 @@ public abstract class BaseDataSource implements Referenceable
     private int portNumber = 0;
     private int prepareThreshold = 5;
     private int unknownLength = Integer.MAX_VALUE;
+    private boolean binaryTransfer = true;
+    private String binaryTransferEnable = "";
+    private String binaryTransferDisable = "";
     private int loginTimeout = 0; // in seconds
     private int socketTimeout = 0; // in seconds
+    private int receiveBufferSize = -1; // off (-1), not in use
+    private int sendBufferSize = -1; // off (-1), not in use
     private boolean ssl = false;
     private String sslfactory;
     private boolean tcpKeepAlive = false;
@@ -188,7 +191,7 @@ public abstract class BaseDataSource implements Referenceable
         return protocolVersion;
     }
 
-    public void setProtocolVersion(int protocolversion)
+    public void setProtocolVersion(int protocolVersion)
     {
         this.protocolVersion = protocolVersion;
     }
@@ -291,6 +294,22 @@ public abstract class BaseDataSource implements Referenceable
         this.prepareThreshold = count;
     }
 
+    /**
+     * Sets the write buffer size of TCP/IP socket.
+     */
+    public void setReceiveBufferSize(int nbytes)
+    {
+        this.receiveBufferSize = nbytes;
+    }
+
+    /**
+     * Sets the send buffer size of TCP/IP socket.
+     */
+    public void setSendBufferSize(int nbytes)
+    {
+        this.sendBufferSize = nbytes;
+    }
+
     /**
      * Gets the default threshold for enabling server-side prepare.
      *
@@ -389,6 +408,68 @@ public abstract class BaseDataSource implements Referenceable
         return tcpKeepAlive;
     }
 
+    /**
+     * Sets protocol transfer mode.
+     *
+     * @param enabled True if the binary transfer mode is used for supported field types,
+     * false if text based transfer is used.
+     */
+    public void setBinaryTransfer(boolean enabled)
+    {
+        this.binaryTransfer = enabled;
+    }
+
+    /**
+     * Gets the protocol transfer mode.
+     *
+     * @see #setBinaryTransfer(boolean)
+     */
+    public boolean getBinaryTransfer()
+    {
+        return binaryTransfer;
+    }
+
+    /**
+     * Add types to the override set of {@link org.postgresql.core.Oid} values used for binary transfer.
+     *
+     * @param oidList The comma separated list of Oids. Either textual or numeric value. 
+     */
+    public void setBinaryTransferEnable(String oidList)
+    {
+        this.binaryTransferEnable = oidList;
+    }
+
+    /**
+     * Gets override set of Oid values that have binary transfer enabled.  
+     *
+     * @see #setBinaryTransferEnable(String)
+     */
+    public String getBinaryTransferEnable()
+    {
+        return binaryTransferEnable;
+    }
+
+    /**
+     * Add types to the override set of {@link org.postgresql.core.Oid} values that will not be used for binary transfer.
+     * This overrides any values in the driver detault set or values set with {@link #setBinaryTransferEnable(String)}.
+     *
+     * @param oidList The comma separated list of Oids. Either textual or numeric value. 
+     */
+    public void setBinaryTransferDisable(String oidList)
+    {
+        this.binaryTransferDisable = oidList;
+    }
+
+    /**
+     * Gets override set of Oid values that have binary transfer disabled.  
+     *
+     * @see #setBinaryTransferDisable(String)
+     */
+    public String getBinaryTransferDisable()
+    {
+        return binaryTransferDisable;
+    }
+
     /**
      * Generates a DriverManager URL from the other properties supplied.
      */
@@ -415,6 +496,12 @@ public abstract class BaseDataSource implements Referenceable
                 sb.append("&sslfactory=").append(sslfactory);
             }
         }
+        if (receiveBufferSize != -1) {
+            sb.append("&receiveBufferSize=").append(receiveBufferSize);
+        }
+        if (sendBufferSize != -1) {
+            sb.append("&sendBufferSize=").append(sendBufferSize);
+        }
         sb.append("&tcpkeepalive=").append(tcpKeepAlive);
         if (compatible != null) {
             sb.append("&compatible="+compatible);
@@ -423,6 +510,9 @@ public abstract class BaseDataSource implements Referenceable
             sb.append("&ApplicationName=");
             sb.append(applicationName);
         }
+        if (binaryTransfer) {
+        	sb.append("&binaryTransfer=true");
+        }
 
         return sb.toString();
     }
@@ -457,12 +547,15 @@ public abstract class BaseDataSource implements Referenceable
         
         ref.add(new StringRefAddr("prepareThreshold", Integer.toString(prepareThreshold)));
         ref.add(new StringRefAddr("unknownLength", Integer.toString(unknownLength)));
+        ref.add(new StringRefAddr("binaryTransfer", Boolean.toString(binaryTransfer)));
         ref.add(new StringRefAddr("loginTimeout", Integer.toString(loginTimeout)));
         ref.add(new StringRefAddr("socketTimeout", Integer.toString(socketTimeout)));
 
         ref.add(new StringRefAddr("ssl", Boolean.toString(ssl)));
         ref.add(new StringRefAddr("sslfactory", sslfactory));
 
+        ref.add(new StringRefAddr("receiveBufferSize", Integer.toString(receiveBufferSize)));
+        ref.add(new StringRefAddr("sendBufferSize", Integer.toString(sendBufferSize)));
         ref.add(new StringRefAddr("tcpKeepAlive", Boolean.toString(tcpKeepAlive)));
         if (compatible != null)
         {
@@ -489,11 +582,16 @@ public abstract class BaseDataSource implements Referenceable
         out.writeInt(socketTimeout);
         out.writeBoolean(ssl);
         out.writeObject(sslfactory);
+        out.writeInt(receiveBufferSize);
+        out.writeInt(sendBufferSize);
         out.writeBoolean(tcpKeepAlive);
         out.writeObject(compatible);
         out.writeInt(logLevel);
         out.writeInt(protocolVersion);
         out.writeObject(applicationName);
+        out.writeBoolean(binaryTransfer);
+        out.writeObject(binaryTransferEnable);
+        out.writeObject(binaryTransferDisable);
     }
 
     protected void readBaseObject(ObjectInputStream in) throws IOException, ClassNotFoundException
@@ -509,11 +607,16 @@ public abstract class BaseDataSource implements Referenceable
         socketTimeout = in.readInt();
         ssl = in.readBoolean();
         sslfactory = (String)in.readObject();
+        receiveBufferSize = in.readInt();
+        sendBufferSize = in.readInt();
         tcpKeepAlive = in.readBoolean();
         compatible = (String)in.readObject();
         logLevel = in.readInt();
         protocolVersion = in.readInt();
         applicationName = (String)in.readObject();
+        binaryTransfer = in.readBoolean();
+        binaryTransferEnable = (String)in.readObject();
+        binaryTransferDisable = (String)in.readObject();
     }
 
     public void initializeFrom(BaseDataSource source) throws IOException, ClassNotFoundException {
