@@ -2,8 +2,6 @@
 *
 * Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/ds/common/PGObjectFactory.java,v 1.7 2011/08/02 13:42:25 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -114,6 +112,18 @@ public class PGObjectFactory implements ObjectFactory
         if (prepareThreshold != null)
             ds.setPrepareThreshold(Integer.parseInt(prepareThreshold));
 
+        String binaryTransfer = getProperty(ref, "binaryTransfer");
+        if (binaryTransfer != null)
+            ds.setBinaryTransfer(Boolean.getBoolean(binaryTransfer));
+
+        String binaryTransferEnable = getProperty(ref, "binaryTransferEnable");
+        if (binaryTransferEnable != null)
+            ds.setBinaryTransferEnable(binaryTransferEnable);
+
+        String binaryTransferDisable = getProperty(ref, "binaryTransferDisable");
+        if (binaryTransferDisable != null)
+            ds.setBinaryTransferDisable(binaryTransferDisable);
+
         return ds;
     }
 
