@@ -2,8 +2,6 @@
 *
 * Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/jdbc2/AbstractJdbc2Connection.java,v 1.56 2011/08/02 13:48:35 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -13,15 +11,15 @@ import java.io.IOException;
 import java.io.PrintWriter;
 import java.sql.*;
 import java.util.*;
+
 import org.postgresql.core.*;
+
 import org.postgresql.Driver;
 import org.postgresql.PGNotification;
 import org.postgresql.fastpath.Fastpath;
 import org.postgresql.largeobject.LargeObjectManager;
-import org.postgresql.util.PSQLState;
-import org.postgresql.util.PGobject;
-import org.postgresql.util.PSQLException;
-import org.postgresql.util.GT;
+import org.postgresql.util.*;
+import org.postgresql.util.HostSpec;
 import org.postgresql.copy.*;
 
 /**
@@ -74,12 +72,17 @@ public abstract class AbstractJdbc2Connection implements BaseConnection
     // Current warnings; there might be more on protoConnection too.
     public SQLWarning firstWarning = null;
 
+    /** Set of oids that use binary transfer when sending to server. */
+    private Set<Integer> useBinarySendForOids;
+    /** Set of oids that use binary transfer when receiving from server. */
+    private Set<Integer> useBinaryReceiveForOids;
+
     public abstract DatabaseMetaData getMetaData() throws SQLException;
 
     //
     // Ctor.
     //
-    protected AbstractJdbc2Connection(String host, int port, String user, String database, Properties info, String url) throws SQLException
+    protected AbstractJdbc2Connection(HostSpec[] hostSpecs, String user, String database, Properties info, String url) throws SQLException
     {
         this.creatingURL = url;
 
@@ -116,21 +119,96 @@ public abstract class AbstractJdbc2Connection implements BaseConnection
         catch (Exception e)
         {
         }
+        boolean binaryTransfer = true;
+        try
+        {
+            binaryTransfer = Boolean.valueOf(info.getProperty("binaryTransfer", "true")).booleanValue();
+        }
+        catch (Exception e)
+        {
+        }
 
         //Print out the driver version number
         if (logger.logInfo())
             logger.info(Driver.getVersion());
 
         // Now make the initial connection and set up local state
-        this.protoConnection = ConnectionFactory.openConnection(host, port, user, database, info, logger);
+        this.protoConnection = ConnectionFactory.openConnection(hostSpecs, user, database, info, logger);
         this.dbVersionNumber = protoConnection.getServerVersion();
         this.compatible = info.getProperty("compatible", Driver.MAJORVERSION + "." + Driver.MINORVERSION);
 
+        // Formats that currently have binary protocol support
+        Set<Integer> binaryOids = new HashSet<Integer>();
+        if (binaryTransfer && protoConnection.getProtocolVersion() >= 3) {
+            binaryOids.add(Oid.BYTEA);
+            binaryOids.add(Oid.INT2);
+            binaryOids.add(Oid.INT4);
+            binaryOids.add(Oid.INT8);
+            binaryOids.add(Oid.FLOAT4);
+            binaryOids.add(Oid.FLOAT8);
+            binaryOids.add(Oid.TIME);
+            binaryOids.add(Oid.DATE);
+            binaryOids.add(Oid.TIMETZ);
+            binaryOids.add(Oid.TIMESTAMP);
+            binaryOids.add(Oid.TIMESTAMPTZ);
+            binaryOids.add(Oid.INT2_ARRAY);
+            binaryOids.add(Oid.INT4_ARRAY);
+            binaryOids.add(Oid.INT8_ARRAY);
+            binaryOids.add(Oid.FLOAT4_ARRAY);
+            binaryOids.add(Oid.FLOAT8_ARRAY);
+            binaryOids.add(Oid.FLOAT8_ARRAY);
+            binaryOids.add(Oid.VARCHAR_ARRAY);
+            binaryOids.add(Oid.TEXT_ARRAY);
+            binaryOids.add(Oid.POINT);
+            binaryOids.add(Oid.BOX);
+            binaryOids.add(Oid.UUID);
+        }        
+        // the pre 8.0 servers do not disclose their internal encoding for
+        // time fields so do not try to use them.
+        if (!haveMinimumCompatibleVersion("8.0")) {
+            binaryOids.remove(Oid.TIME);
+            binaryOids.remove(Oid.TIMETZ);
+            binaryOids.remove(Oid.TIMESTAMP);
+            binaryOids.remove(Oid.TIMESTAMPTZ);
+        }
+        // driver supports only null-compatible arrays
+        if (!haveMinimumCompatibleVersion("8.3")) {
+            binaryOids.remove(Oid.INT2_ARRAY);
+            binaryOids.remove(Oid.INT4_ARRAY);
+            binaryOids.remove(Oid.INT8_ARRAY);
+            binaryOids.remove(Oid.FLOAT4_ARRAY);
+            binaryOids.remove(Oid.FLOAT8_ARRAY);
+            binaryOids.remove(Oid.FLOAT8_ARRAY);
+            binaryOids.remove(Oid.VARCHAR_ARRAY);
+            binaryOids.remove(Oid.TEXT_ARRAY);
+        }
+
+        binaryOids.addAll(getOidSet(info.getProperty("binaryTransferEnable", "")));
+        binaryOids.removeAll(getOidSet(info.getProperty("binaryTransferDisable", "")));
+
+        // split for receive and send for better control
+        useBinarySendForOids = new HashSet<Integer>();
+        useBinarySendForOids.addAll(binaryOids);
+        useBinaryReceiveForOids = new HashSet<Integer>();
+        useBinaryReceiveForOids.addAll(binaryOids);
+
+        /*
+         * Does not pass unit tests because unit tests expect setDate to have
+         * millisecond accuracy whereas the binary transfer only supports
+         * date accuracy.
+         */
+        useBinarySendForOids.remove(Oid.DATE);
+
+        protoConnection.setBinaryReceiveOids(useBinaryReceiveForOids);
+
         if (logger.logDebug())
         {
             logger.debug("    compatible = " + compatible);
             logger.debug("    loglevel = " + logLevel);
             logger.debug("    prepare threshold = " + prepareThreshold);
+            logger.debug("    types using binary send = " + oidsToString(useBinarySendForOids));
+            logger.debug("    types using binary receive = " + oidsToString(useBinaryReceiveForOids));
+            logger.debug("    integer date/time = " + protoConnection.getIntegerDateTimes());
         }
 
         //
@@ -151,7 +229,8 @@ public abstract class AbstractJdbc2Connection implements BaseConnection
         }
 
         // Initialize timestamp stuff
-        timestampUtils = new TimestampUtils(haveMinimumServerVersion("7.4"), haveMinimumServerVersion("8.2"));
+        timestampUtils = new TimestampUtils(haveMinimumServerVersion("7.4"), haveMinimumServerVersion("8.2"),
+                                            !protoConnection.getIntegerDateTimes());
 
         // Initialize common queries.
         commitQuery = getQueryExecutor().createSimpleQuery("COMMIT");
@@ -177,6 +256,30 @@ public abstract class AbstractJdbc2Connection implements BaseConnection
         }
     }
 
+    private Set<Integer> getOidSet(String oidList) throws PSQLException {
+        Set oids = new HashSet();
+        StringTokenizer tokenizer = new StringTokenizer(oidList, ",");
+        while (tokenizer.hasMoreTokens()) {
+            String oid = tokenizer.nextToken();
+            oids.add(Oid.valueOf(oid));
+        }
+        return oids;
+    }
+
+    private String oidsToString(Set<Integer> oids) {
+        StringBuffer sb = new StringBuffer();
+        for (Integer oid : oids) {
+            sb.append(Oid.toString(oid));
+            sb.append(',');
+        }
+        if (sb.length() > 0) {
+            sb.setLength(sb.length() - 1);
+        } else {
+            sb.append(" <none>");
+        }
+        return sb.toString();
+    }
+
     private final TimestampUtils timestampUtils;
     public TimestampUtils getTimestampUtils() { return timestampUtils; }
 
@@ -395,7 +498,7 @@ public abstract class AbstractJdbc2Connection implements BaseConnection
      * This method is used internally to return an object based around
      * org.postgresql's more unique data types.
      *
-     * <p>It uses an internal Hashtable to get the handling class. If the
+     * <p>It uses an internal HashMap to get the handling class. If the
      * type is not supported, then an instance of org.postgresql.util.PGobject
      * is returned.
      *
@@ -405,7 +508,7 @@ public abstract class AbstractJdbc2Connection implements BaseConnection
      * @return PGobject for this type, and set to value
      * @exception SQLException if value is not correct for this type
      */
-    public Object getObject(String type, String value) throws SQLException
+    public Object getObject(String type, String value, byte[] byteValue) throws SQLException
     {
         if (typemap != null)
         {
@@ -436,7 +539,12 @@ public abstract class AbstractJdbc2Connection implements BaseConnection
             {
                 obj = (PGobject) (klass.newInstance());
                 obj.setType(type);
-                obj.setValue(value);
+                if (byteValue != null && obj instanceof PGBinaryObject) {
+                    PGBinaryObject binObj = (PGBinaryObject) obj;
+                    binObj.setByteValue(byteValue, 0);
+                } else {
+                    obj.setValue(value);
+                }
             }
             else
             {
@@ -488,7 +596,7 @@ public abstract class AbstractJdbc2Connection implements BaseConnection
         _typeCache.addDataType(type, klass);
     }
 
-    // This initialises the objectTypes hashtable
+    // This initialises the objectTypes hash map
     private void initObjectTypes(Properties info) throws SQLException
     {
         // Add in the types that come packaged with the driver.
@@ -1040,7 +1148,7 @@ public abstract class AbstractJdbc2Connection implements BaseConnection
     private class TransactionCommandHandler implements ResultHandler {
         private SQLException error;
 
-        public void handleResultRows(Query fromQuery, Field[] fields, Vector tuples, ResultCursor cursor) {
+        public void handleResultRows(Query fromQuery, Field[] fields, List tuples, ResultCursor cursor) {
         }
         public void handleCommandStatus(String status, int updateCount, long insertOID) {
         }
@@ -1111,4 +1219,8 @@ public abstract class AbstractJdbc2Connection implements BaseConnection
             copyManager = new CopyManager(this);
         return copyManager;
     }
+
+    public boolean binaryTransferSend(int oid) {
+        return useBinarySendForOids.contains(oid);
+    }
 }
