@@ -2,8 +2,6 @@
 *
 * Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/jdbc2/AbstractJdbc2ResultSetMetaData.java,v 1.26 2011/08/02 13:48:35 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -14,7 +12,6 @@ import org.postgresql.core.*;
 import org.postgresql.util.PSQLException;
 import org.postgresql.util.PSQLState;
 import java.sql.*;
-import java.util.Hashtable;
 import org.postgresql.util.GT;
 
 public abstract class AbstractJdbc2ResultSetMetaData implements PGResultSetMetaData
@@ -239,8 +236,8 @@ public abstract class AbstractJdbc2ResultSetMetaData implements PGResultSetMetaD
         Statement stmt = connection.createStatement();
         ResultSet rs = stmt.executeQuery(sql.toString());
         while (rs.next()) {
-            int table = rs.getInt(1);
-            int column = rs.getInt(2);
+            int table = (int)rs.getLong(1);
+            int column = (int)rs.getLong(2);
             String columnName = rs.getString(3);
             String tableName = rs.getString(4);
             String schemaName = rs.getString(5);
