@@ -2,8 +2,6 @@
 *
 * Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/jdbc3/Jdbc3Array.java,v 1.7 2011/08/02 13:49:01 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -21,6 +19,11 @@ public class Jdbc3Array extends org.postgresql.jdbc2.AbstractJdbc2Array implemen
         super(conn, oid, fieldString);
     }
 
+    public Jdbc3Array(BaseConnection conn, int oid, byte[] fieldBytes) throws SQLException
+    {
+        super(conn, oid, fieldBytes);
+    }
+
     public Object getArray(Map map) throws SQLException
     {
         return getArrayImpl(map);
