@@ -2,8 +2,6 @@
 *
 * Copyright (c) 2008-2011, PostgreSQL Global Development Group
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/jdbc3g/AbstractJdbc3gResultSet.java,v 1.3 2011/08/02 14:41:30 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -11,10 +9,11 @@
 package org.postgresql.jdbc3g;
 
 import java.sql.*;
+import java.util.List;
 import java.util.UUID;
-import java.util.Vector;
 
 import org.postgresql.core.*;
+import org.postgresql.util.ByteConverter;
 import org.postgresql.util.GT;
 import org.postgresql.util.PSQLState;
 import org.postgresql.util.PSQLException;
@@ -22,7 +21,7 @@ import org.postgresql.util.PSQLException;
 public abstract class AbstractJdbc3gResultSet extends org.postgresql.jdbc3.AbstractJdbc3ResultSet
 {
 
-    public AbstractJdbc3gResultSet(Query originalQuery, BaseStatement statement, Field[] fields, Vector tuples,
+    public AbstractJdbc3gResultSet(Query originalQuery, BaseStatement statement, Field[] fields, List tuples,
                                   ResultCursor cursor, int maxRows, int maxFieldSize, int rsType, int rsConcurrency, int rsHoldability) throws SQLException
     {
         super (originalQuery, statement, fields, tuples, cursor, maxRows, maxFieldSize, rsType, rsConcurrency, rsHoldability);
@@ -40,5 +39,10 @@ public abstract class AbstractJdbc3gResultSet extends org.postgresql.jdbc3.Abstr
 
         return uuid;
     }
+
+    protected Object getUUID(byte[] data) throws SQLException
+    {
+        return new UUID(ByteConverter.int8(data, 0), ByteConverter.int8(data, 8));
+    }
 }
 
