@@ -2,8 +2,6 @@
 *
 * Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/jdbc4/Jdbc4Array.java,v 1.5 2011/08/02 13:49:23 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -21,6 +19,11 @@ public class Jdbc4Array extends org.postgresql.jdbc2.AbstractJdbc2Array implemen
         super(conn, oid, fieldString);
     }
 
+    public Jdbc4Array(BaseConnection conn, int oid, byte[] fieldBytes) throws SQLException
+    {
+        super(conn, oid, fieldBytes);
+    }
+
     public Object getArray(Map < String, Class < ? >> map) throws SQLException
     {
         return getArrayImpl(map);
