@@ -2,8 +2,6 @@
 *
 * Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/jdbc4/Jdbc4Connection.java,v 1.4 2011/08/02 13:49:23 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -13,6 +11,8 @@ import java.util.Map;
 import java.util.Properties;
 import java.sql.SQLException;
 
+import org.postgresql.util.HostSpec;
+
 /**
  * This class implements the java.sql.Connection interface for JDBC4.
  * However most of the implementation is really done in
@@ -20,8 +20,8 @@ import java.sql.SQLException;
  */
 public class Jdbc4Connection extends AbstractJdbc4Connection implements java.sql.Connection
 {
-    public Jdbc4Connection(String host, int port, String user, String database, Properties info, String url) throws SQLException {
-        super(host, port, user, database, info, url);
+    public Jdbc4Connection(HostSpec[] hostSpecs, String user, String database, Properties info, String url) throws SQLException {
+        super(hostSpecs, user, database, info, url);
     }
 
     public java.sql.Statement createStatement(int resultSetType, int resultSetConcurrency, int resultSetHoldability) throws SQLException
