@@ -2,8 +2,6 @@
 *
 * Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/jdbc4/Jdbc4ResultSet.java,v 1.6 2011/08/02 13:49:23 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -11,8 +9,8 @@ package org.postgresql.jdbc4;
 
 
 import java.sql.*;
+import java.util.List;
 import java.util.Map;
-import java.util.Vector;
 import org.postgresql.core.*;
 
 /**
@@ -22,41 +20,34 @@ import org.postgresql.core.*;
  */
 public class Jdbc4ResultSet extends AbstractJdbc4ResultSet implements java.sql.ResultSet
 {
-    Jdbc4ResultSet(Query originalQuery, BaseStatement statement, Field[] fields, Vector tuples, ResultCursor cursor,
+    Jdbc4ResultSet(Query originalQuery, BaseStatement statement, Field[] fields, List tuples, ResultCursor cursor,
                     int maxRows, int maxFieldSize, int rsType, int rsConcurrency, int rsHoldability) throws SQLException
     {
         super(originalQuery, statement, fields, tuples, cursor, maxRows, maxFieldSize, rsType, rsConcurrency, rsHoldability);
     }
 
-    public java.sql.ResultSetMetaData getMetaData() throws SQLException
+    protected java.sql.ResultSetMetaData createMetaData() throws SQLException
     {
-        checkClosed();
         return new Jdbc4ResultSetMetaData(connection, fields);
     }
 
-    public java.sql.Clob getClob(int i) throws SQLException
+    protected java.sql.Clob makeClob(long oid) throws SQLException
     {
-        checkResultSet(i);
-        if (wasNullFlag)
-            return null;
-
-        return new Jdbc4Clob(connection, getLong(i));
+        return new Jdbc4Clob(connection, oid);
     }
 
-    public java.sql.Blob getBlob(int i) throws SQLException
+    protected java.sql.Blob makeBlob(long oid) throws SQLException
     {
-        checkResultSet(i);
-        if (wasNullFlag)
-            return null;
-
-        return new Jdbc4Blob(connection, getLong(i));
+        return new Jdbc4Blob(connection, oid);
     }
 
-    public Array createArray(int i) throws SQLException
+    protected Array makeArray(int oid, byte[] value) throws SQLException
+    {
+        return new Jdbc4Array(connection, oid, value);
+    }
+
+    protected Array makeArray(int oid, String value) throws SQLException
     {
-        checkResultSet(i);
-        int oid = fields[i - 1].getOID();
-        String value = getFixedString(i);
         return new Jdbc4Array(connection, oid, value);
     }
 
