@@ -2,15 +2,13 @@
 *
 * Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/jdbc4/Jdbc4Statement.java,v 1.3 2011/08/02 13:49:23 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
 package org.postgresql.jdbc4;
 
 import java.sql.*;
-import java.util.Vector;
+import java.util.List;
 import org.postgresql.core.*;
 
 /**
@@ -30,7 +28,7 @@ class Jdbc4Statement extends AbstractJdbc4Statement implements Statement
         super(connection, sql, isCallable, rsType, rsConcurrency, rsHoldability);
     }
 
-    public ResultSet createResultSet (Query originalQuery, Field[] fields, Vector tuples, ResultCursor cursor)
+    public ResultSet createResultSet (Query originalQuery, Field[] fields, List tuples, ResultCursor cursor)
     throws SQLException
     {
         Jdbc4ResultSet newResult = new Jdbc4ResultSet(originalQuery, this, fields, tuples, cursor,
