@@ -2,13 +2,14 @@
 *
 * Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/test/TestUtil.java,v 1.24 2011/08/02 13:50:29 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
 package org.postgresql.test;
 
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.IOException;
 import java.sql.*;
 import java.util.Properties;
 
@@ -29,13 +30,31 @@ public class TestUtil
             protocolVersion = "&protocolVersion=" + getProtocolVersion();
         }
 
+        String binaryTransfer = "";
+        if (getBinaryTransfer() != null && !getBinaryTransfer().equals("")) {
+            binaryTransfer = "&binaryTransfer=" + getBinaryTransfer();
+        }
+
+		String receiveBufferSize = "";
+		if (getReceiveBufferSize() != -1 ){
+			receiveBufferSize = "&receiveBufferSize="+getReceiveBufferSize();
+		}
+		
+		String sendBufferSize = "";
+		if (getSendBufferSize() != -1 ){
+			sendBufferSize = "&sendBufferSize="+getSendBufferSize();
+		}
+		
         return "jdbc:postgresql://"
                                 + getServer() + ":" 
                                 + getPort() + "/" 
                                 + getDatabase() 
                                 + "?prepareThreshold=" + getPrepareThreshold()
                                 + "&loglevel=" + getLogLevel()
-                                + protocolVersion;
+                                + protocolVersion
+                                + binaryTransfer
+								+ receiveBufferSize
+								+ sendBufferSize;
     }
 
     /*
@@ -43,7 +62,7 @@ public class TestUtil
      */
     public static String getServer()
     {
-        return System.getProperty("server");
+        return System.getProperty("server", "localhost");
     }
 
     /*
@@ -51,7 +70,7 @@ public class TestUtil
      */
     public static int getPort()
     {
-        return Integer.parseInt(System.getProperty("port"));
+        return Integer.parseInt(System.getProperty("port", System.getProperty("def_pgport")));
     }
 
     /*
@@ -59,12 +78,12 @@ public class TestUtil
      */
     public static int getPrepareThreshold()
     {
-        return Integer.parseInt(System.getProperty("preparethreshold"));
+        return Integer.parseInt(System.getProperty("preparethreshold", "5"));
     }
 
     public static int getProtocolVersion()
     {
-        return Integer.parseInt(System.getProperty("protocolVersion"));
+        return Integer.parseInt(System.getProperty("protocolVersion", "0"));
     }
 
     /*
@@ -96,9 +115,27 @@ public class TestUtil
      */
     public static int getLogLevel()
     {
-        return Integer.parseInt(System.getProperty("loglevel"));
+        return Integer.parseInt(System.getProperty("loglevel", "0"));
     }
 
+    /*
+     * Returns the binary transfer mode to use
+     */
+    public static String getBinaryTransfer()
+    {
+        return System.getProperty("binaryTransfer");
+    }
+	
+	public static int getSendBufferSize()
+	{
+		return Integer.parseInt(System.getProperty("sendBufferSize", "-1"));
+	}
+	
+	public static int getReceiveBufferSize()
+	{
+		return Integer.parseInt(System.getProperty("receiveBufferSize","-1"));
+	}
+	
     private static boolean initialized = false;
     public static void initDriver() throws Exception
     {
@@ -106,6 +143,16 @@ public class TestUtil
             if (initialized)
                 return;
 
+            Properties p = new Properties();
+            try {
+              p.load(new FileInputStream("build.properties"));
+              p.load(new FileInputStream("build.local.properties"));
+            } catch (IOException ex) {
+              // ignore
+            }
+            p.putAll(System.getProperties());
+            System.getProperties().putAll(p);
+
             if (getLogLevel() > 0) { 
                 // Ant's junit task likes to buffer stdout/stderr and tends to run out of memory.
                 // So we put debugging output to a file instead.
