@@ -2,8 +2,6 @@
 *
 * Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/test/jdbc2/Jdbc2TestSuite.java,v 1.27 2011/08/02 13:50:29 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -90,7 +88,8 @@ public class Jdbc2TestSuite extends TestSuite
         suite.addTestSuite(GeometricTest.class);
 
         suite.addTestSuite(LoginTimeoutTest.class);
-
+        suite.addTestSuite(TestACL.class);
+        
         Connection conn = TestUtil.openDB();
         if (TestUtil.isProtocolVersion(conn, 3)) {
             suite.addTestSuite(CopyTest.class);
