@@ -2,8 +2,6 @@
 *
 * Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/test/jdbc2/StatementTest.java,v 1.30 2011/08/02 13:50:29 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -12,6 +10,8 @@ package org.postgresql.test.jdbc2;
 import org.postgresql.test.TestUtil;
 import junit.framework.*;
 import java.sql.*;
+import java.util.Timer;
+import java.util.TimerTask;
 /*
  * Test for getObject
  */
@@ -477,5 +477,38 @@ public class StatementTest extends TestCase
             fail("Should have thrown an error.");
         } catch (SQLException sqle) { }
     }
+    public void testSetQueryTimeout() throws SQLException
+    {
+    	Statement stmt = con.createStatement();
+    	Timer timer = new Timer(true);
+    	try
+    	{
+    		
+    		timer.schedule( new TimerTask(){
+    			public void run() 
+    			{
+    				fail("Query timeout should have occured and cleaned this up");
+    			}
+    		}, 5000);
+    		stmt.setQueryTimeout(1);
+    		stmt.execute("select pg_sleep(10)");
+    		
+    	}catch( SQLException sqle )
+    	{
+    		// state for cancel    		
+    		if (sqle.getSQLState().compareTo("57014") == 0) 
+    			timer.cancel();
+    	}
+    }
 
+    public void testResultSetTwice() throws SQLException
+    {
+        Statement stmt = con.createStatement();
+
+        ResultSet rs = stmt.executeQuery("select {fn abs(-2.3)} as abs ");
+        assertNotNull(rs);
+
+        ResultSet rsOther = stmt.getResultSet();
+        assertNotNull(rsOther);
+    }
 }
