@@ -2,8 +2,6 @@
 *
 * Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/test/jdbc3/Jdbc3TestSuite.java,v 1.20 2011/08/02 13:50:29 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -51,6 +49,7 @@ public class Jdbc3TestSuite extends TestSuite
         suite.addTestSuite(ParameterMetaDataTest.class);
         suite.addTestSuite(Jdbc3BlobTest.class);
         suite.addTestSuite(DatabaseMetaDataTest.class);
+		suite.addTestSuite(SendRecvBufferSizeTest.class);
         return suite;
     }
 }
