@@ -2,14 +2,13 @@
 *
 * Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
-* IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/util/ServerErrorMessage.java,v 1.14 2011/08/02 13:50:29 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
 package org.postgresql.util;
 
-import java.util.Hashtable;
+import java.util.HashMap;
+import java.util.Map;
 import java.io.Serializable;
 
 public class ServerErrorMessage implements Serializable
@@ -28,7 +27,7 @@ public class ServerErrorMessage implements Serializable
     private static final Character INTERNAL_POSITION = new Character('p');
     private static final Character INTERNAL_QUERY = new Character('q');
 
-    private final Hashtable m_mesgParts = new Hashtable();
+    private final Map m_mesgParts = new HashMap();
     private final int verbosity;
 
     public ServerErrorMessage(String p_serverError, int verbosity)
@@ -45,7 +44,8 @@ public class ServerErrorMessage implements Serializable
             {
                 l_pos++;
                 int l_startString = l_pos;
-                while (l_chars[l_pos] != '\0' && l_pos < l_length)
+				// order here is important position must be checked before accessing the array
+                while ( l_pos < l_length && l_chars[l_pos] != '\0' )
                 {
                     l_pos++;
                 }
